unit FontExportPlugin;

interface

// FONT STUDIO EXPORT PLUGIN TYPES
// -------------------------------

// Author: Michael Pote
// Email: mikepote@gmail.com
// Revision: 2.0

// This unit provides the interface between Font Studio and your plugin.
//
// Font Studio will call functions GetPluginVersion then GetPluginInfo to find out about your plugin.
// Your plugin must implement these functions or else Font Studio will not accept your plugin.
//  GetPluginVersion is a function of type TPluginVersionProc
//  GetPluginInfo is a function of type TPluginGetInfoProc
//
//  If GetPluginVersion doesnt exist or returns fntPluginVersion1, then Font Studio assumes you
//   will provide GetPluginInfo with a TPluginInfoOld record.
//
// Each plugin needs to specify what type of data it will handle in the TPluginInfo record returned from GetPluginInfo:
//
// ptSimple: The plugin will handle all data: colour data, alpha channel data and character position data.
// ptData: Only the positions of the characters are sent to the plugin, no bitmaps.
// ptRGB: Only the colour bitmap channels are sent to the plugin.
// ptAlpha: Only the alpha channel bitmap data is sent to the plugin.
// ptRGBorAlpha: Either RGB or Alpha data is sent, not both.
// ptRGBandAlpha: Both RGB and Alpha data are sent.
// ptRGBandorAlpha: Either RGB or Alpha data is sent, or both, but never neither.
//
//
//
//
//Font Studio will call one of 3 predefined functions depending on what plugin type is specified:
//
// ptSimple:
//
//          Procedure SimpleExport(const Data: TSimpleData); cdecl; export;
//
// ptRGB, ptAlpha, ptRGBorAlpha, ptRGBandorAlpha, ptRGBandAlpha:
//
//          Procedure GraphicExport(const Data: TGraphicsData); cdecl; export;
// ptData:
//          Procedure DataExport(const Data: TCharactersData); cdecl; export;
//
//
//

const
     //Plugin Type
     ptSimple        = 1; //plugin is sent all the data
     ptData          = 2;
     ptRGB           = 3;
     ptAlpha         = 4;
     ptRGBorAlpha    = 5;
     ptRGBandAlpha   = 6;
     ptRGBandorAlpha = 7;
     ptRGBoptionalAlpha = 8;

     fntPluginVersion1 = 1;
     fntPluginVersion2 = 2;


type

      //This TPluginInfo should only be used with fntPluginVersion2 plugins.
      TPluginInfo = packed record
                     Name: shortstring;
                     PluginType: byte; //See types above.

                     poWantFilename: boolean; //Font Studio will display the Save dialog and send the filename to the plugin.
                     poHasExtension: boolean; //Fontstudio will be able to filter dialogs and add extensions to the end of filenames.

                     Ext: shortstring; //Needed if poHasExtension is true

                   end;


      //Do not use - For backward compatibility.
      TPluginInfoOld = packed record
                     Version: integer;
                     Name: shortstring;
                     PluginType: byte; //See types above.

                     poWantFilename: boolean; //Font Studio will display the Save dialog and send the filename to the plugin.
                     poHasExtension: boolean; //Fontstudio will be able to filter dialogs and add extensions to the end of filenames.

                     Ext: string[3]; //Needed if poHasExtension is true

                   end;


     TCharacterData = packed record    //This is how the plugin will recieve FontData - an array of TCharacterData
      Wid,Hgt, X,Y: cardinal;          //Unsigned 32bit
      A, C: integer;                   //Signed 32bit
      char: cardinal;                  //The actual unicode character number

      //X,Y is the position of the character block on the texture
      //Wid, Hgt is the width and height of the character on the texture
      //To be used in conjunction with TCharactersData.TexWidth and TexHeight.
     end;
     pCharacterData = ^TCharacterData;

     TSimpleData = packed record
         Filename: pansichar; //This is only valid if poWantFilename is set.
         TexWidth, TexHeight: word;
         RGB,            //Array of bytes wid x hgt x 3
         Alpha: PByte;   //Array of bytes wid x hgt x 1
         NumChars, SpaceWidth: cardinal;
         CharData: pCharacterData; //Array of TCharacterData
     end;


     TGraphicsData = packed record
         Filename  : pansichar; //This is only valid if poWantFilename is set.
         TexWidth, TexHeight: word;
         RGB,            //Array of bytes wid x hgt x 3
         Alpha: PByte;   //Array of bytes wid x hgt x 1
     end;
     //Note that Fontstudio may not give both RGB and Alpha data, eg. if your plugin
     //only requests RGB (by setting PluginType to ptRGB) then the Alpha field will
     //be nil. And vice verse for ptAlpha type plugins.

     //Plugins that are marked ptRGBandAlpha, ptRGBandorAlpha and ptRGBorAlpha need to
     //check if the RGB data is nil, if not then save it, then check if the
     //Alpha data is nil, if not then save that too.

     //Font studio will ensure that ptRGBorAlpha plugins are sent either the
     //RGB or the Alpha data but not both.

     TCharactersData = packed record
         Filename: pansichar; //This is only valid if poWantFilename is set.
         NumChars,
         SpaceWidth: cardinal; //The width of a space in the font - for convenience.
         TexWidth, TexHeight: word;
         CharData: pCharacterData; //Array of TCharacterData
     end;


     TPluginVersionProc = function():integer; cdecl;
     TPluginGetInfoProc = procedure(var PluginInfo); cdecl;
     TPluginSimpleExportProc = procedure(const Data: TSimpleData); cdecl;
     TPluginGraphicExportProc = procedure(const Data: TGraphicsData); cdecl;
     TPluginDataExportProc = procedure(const Data: TCharactersData); cdecl;


implementation


end.

